"""
MVS Story Generator - A Python library for generating MolViewSpec JSON (MVSJ) files.

This library provides tools for creating molecular visualizations and multi-state stories
using the MolViewSpec JSON format for molecular structure visualization.
"""

__version__ = "0.0.1"
__author__ = "Brian"
__email__ = "brian@junction.bio"

# Import main API
from .visualization import (
    protein_cartoon,
    ligand_view,
    multi_component_colored_view,
    multi_component_ligand_focus,
    protein_surface,
    ligand_surface,
    protein_surface_with_cartoon,
    ligand_surface_with_sticks
)

from .stories import (
    create_multi_state_story,
    protein_rotation_story,
    structure_comparison_story,
    protein_surface_evolution_story,
    ligand_representation_transition_story,
    protein_ligand_surface_story,
    hybrid_representation_showcase_story
)

from .core.builders import save_json
from .core.types import LabelConfig, StateConfig
from .core.docs_export import export_docs_to_txt, export_api_reference_only
from .examples.generator import generate_examples

__all__ = [
    # Core visualization functions
    "protein_cartoon",
    "ligand_view",
    "multi_component_colored_view", 
    "multi_component_ligand_focus",
    
    # Surface visualization functions
    "protein_surface",
    "ligand_surface",
    "protein_surface_with_cartoon",
    "ligand_surface_with_sticks",
    
    # Multi-state story functions
    "create_multi_state_story",
    "protein_rotation_story",
    "structure_comparison_story",
    "protein_surface_evolution_story",
    "ligand_representation_transition_story", 
    "protein_ligand_surface_story",
    "hybrid_representation_showcase_story",
    
    # Utilities
    "save_json",
    "generate_examples",
    "export_docs_to_txt",
    "export_api_reference_only",
    
    # Types
    "LabelConfig",
    "StateConfig"
]