"""
Component consolidation utilities for MVS Story Generator.
"""
from typing import Dict, Any, List, Union
from .builders import _build_component


def _consolidate_components(component_features: Dict[str, Dict]) -> List[Dict[str, Any]]:
    """Consolidate component features by selector to avoid duplicates."""
    components = []
    for selector_key, feature_data in component_features.items():
        if feature_data.get("children"):
            components.append(_build_component(feature_data["selector"], feature_data["children"]))
    return components


def _add_to_component_group(component_features: Dict, selector: Union[str, Dict], feature_node: Dict) -> None:
    """Add feature to component group by selector."""
    # Create stable key for selector
    if isinstance(selector, str):
        selector_key = selector
    else:
        key_parts = [f"{k}:{v}" for k, v in sorted(selector.items())]
        selector_key = "|".join(key_parts)
      
    # Initialize or add to component group
    if selector_key not in component_features:
        component_features[selector_key] = {"selector": selector, "children": []}
    component_features[selector_key]["children"].append(feature_node)